Class: WebBaseController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- WebBaseController
- Includes:
- ActionController::ImplicitRender, ActionView::Layouts
- Defined in:
- app/controllers/web_base_controller.rb
Overview
Base controller for web pages
Instance Method Summary collapse
-
#app ⇒ Object
Renders the angular index view when request url is /app/* to enable html5 pushState capability of angularjs.
Instance Method Details
#app ⇒ Object
Renders the angular index view when request url is /app/* to enable html5 pushState capability of angularjs
8 9 10 |
# File 'app/controllers/web_base_controller.rb', line 8 def app render file: "#{Rails.root}/public/app/index.html", layout: false end |